Learn R Programming

mapfit (version 0.9.6)

map: Markovian Arrival Process (MAP)

Description

Functions to generate an object of map.

Usage

map(size, alpha, D0, D1, class = "CsparseMatrix")
mmpp(size, class = "CsparseMatrix")
gmmpp(size, alpha, D0, D1, class = "dgeMatrix")

Arguments

Value

map gives an object of general MAP. mmpp gives an object of MMPP with default parameters. gmmpp gives an object of MMPP which uses an approximate estimation algorithm.

Details

MAP parameters are $alpha$, $D0$ and $D1$. $alpha$ is the probability vector to determine an initial phase at time 0. $D0$ is an infinitesimal generator of underlyinc continuous-time Markov chain (CTMC) without arrival. $D1$ is an infinitesimal generator of CTMC with arrival. The infinitesimal generator of underlying CTMC becomes $D0+D1$. In the stationary case, $alpha$ is often given by a stationary vector satisfying $alpha (D0+D1) = alpha$.

mmpp generates an object of a specific MAP called MMPP. MMPP (Markov modulated Poisson process) is an MAP whose $D1$ is given by a diagonal matrix. Unlike to general MAPs, MMPP never changes the phase at which an arrival occurs.

gmmpp generates an object of gmmpp, which is exactly same as MMPP. In the estimation algorithm, gmmpp class uses an approximate method.

See Also

erhmm, map.mmoment, map.jmoment, map.acf

Examples

Run this code
## create an MAP (full matrix) with 5 phases
map(5)

## create an MAP (full matrix) with 5 phases
map(size=5)

## create an MMPP with 5 states
mmpp(5)

## create an MMPP with 5 states for approximate
## estimation
gmmpp(5)

## create an MAP with specific parameters
(param <- map(alpha=c(1,0,0),
	D0=rbind(c(-4,2,0),c(2,-5,1),c(1,0,-4)),
	D1=rbind(c(1,1,0),c(1,0,1),c(2,0,1))))

## marginal moments of MAP
map.mmoment(k=3, map=param)

## joint moments of MAP
map.jmoment(lag=1, map=param)

## k-lag correlation
map.acf(map=param)

Run the code above in your browser using DataLab